-- This source file is part of HGamer3D
-- (A project to enable 3D game development in Haskell)
-- For the latest info, see http://www.althainz.de/HGamer3D.html
--
-- (c) 2011 Peter Althainz
--
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License at
--
--     http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.

-- InputSystem.hs

-- |This module is one sub module of the second attempt, to provide an 
-- abstracted interface to the HGamer3D API Bindings. It is named 'Two',
-- submodule Input System and handles Mouse, Keyboard and Joystick Input.

module HGamer3D.APIs.Two.InputSystem

(
	-- Enums
	--
	module HGamer3D.Bindings.SFML.EnumJoystickAxis,
	module HGamer3D.Bindings.SFML.EnumKey,
	module HGamer3D.Bindings.SFML.EnumMouseButton,
	
	-- Joystick Functions
	isJoystickConnected,
	updateJoystickStatus,
	getJoystickButtonCount,
	isJoystickButtonPressed,
	hasJoystickAxis,
	getJoystickPosition,
	
	-- Keyboard Functions
	isKeyPressed,
	
	-- Mouse Functions
	isMouseButtonPressed,
	getMousePosition,
	
	
	
)

where

import GHC.Ptr

import HGamer3D.Bindings.SFML.ClassPtr
import HGamer3D.Bindings.SFML.Utils

import qualified HGamer3D.Bindings.SFML.ClassJoystick as Joystick
import qualified HGamer3D.Bindings.SFML.ClassKeyboard as Keyboard
import qualified HGamer3D.Bindings.SFML.ClassMouse as Mouse
import qualified HGamer3D.Bindings.SFML.ClassMouseHG3D as Mouse2
import HGamer3D.Bindings.SFML.EnumJoystickAxis
import HGamer3D.Bindings.SFML.EnumKey
import HGamer3D.Bindings.SFML.EnumMouseButton

-- Joystick funtions
--

isJoystickConnected = Joystick.isConnected
updateJoystickStatus = Joystick.update
getJoystickButtonCount = Joystick.getButtonCount
isJoystickButtonPressed = Joystick.isButtonPressed
hasJoystickAxis = Joystick.hasAxis
getJoystickPosition = Joystick.getAxisPosition

-- Keyboard functions
--

isKeyPressed = Keyboard.isKeyPressed

-- Mouse functions
--

isMouseButtonPressed = Mouse.isButtonPressed
getMousePosition = Mouse2.getPosition


